''' example: ['carbohydrates'][][ 2 ] ['dietary fiber', 'fiber, total dietary'][][ 6 ] ['sugars, total'][][ 7 ] ['added sugars', 'sugars, added'][][ 8 ] ['fats', 'total fat', 'lipids', 'total lipid (fat)'][][ 3 ] ['monounsaturated fat', 'fatty acids, total monounsaturated'][][ 51 ] ['polyunsaturated fat', 'fatty acids, total polyunsaturated'][][ 15 ] ['saturated fat', 'fatty acids, total saturated'][][ 4 ] ['trans fat', 'fatty acids, total trans'][][ 5 ] problems: If "added sugars" is included, but "sugars, total" isn't, then there's a problem. "sugars, total" mass = "added sugars" mass for others this might include "biological activity", etc. If "dietary fiber" is included, but "carbohydrates" isn't, then there is a problem, since thusly, "carbohydrate mass" = "dietary fiber" mass for others this might include "biological activity", etc. '''